#pragma once
/* -*-c++-*- osgVisual - Copyright (C) 2009-2011 Torben Dannhauer
 *
 * This library is based on OpenSceneGraph, open source and may be redistributed and/or modified under 
 * the terms of the OpenSceneGraph Public License (OSGPL) version 0.0 or
 * (at your option) any later version.  The full license is in LICENSE file
 * included with this distribution, and on the openscenegraph.org website.
 *
 * osgVisual requires for some proprietary modules a license from the correspondig manufacturer.
 * You have to aquire licenses for all used proprietary modules.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * OpenSceneGraph Public License for more details.
*/


#include <osg/Referenced>
#include <osg/Notify>
#include <osgViewer/Viewer>
#include <osgDB/ReadFile>



namespace osgVisual
{

class visual_core : public osg::Referenced
{

public:
	visual_core(osg::ArgumentParser& arguments_);
	void initialize();
	void shutdown();

	bool loadTerrain(osg::ArgumentParser& arguments_);
	bool checkCommandlineArgumentsForFinalErrors();

	void setupScenery();

protected:
	/**
	 * \brief Destrcutor
	 * 
	 */ 
	virtual ~visual_core(void);

private:
	/**
	 * \brief This function starts the main rendering loop
	 * 
	 */ 
	void mainLoop();

	/**
	 * Argument object, with contains all commandline arguments, which where called during programm sstartup
	 */ 
	osg::ArgumentParser& arguments;

	/**
	 * This CSN is at the top node on the complete scenery. Only the nodes for distortion are located above this node.
	 */ 
	osg::ref_ptr<osg::CoordinateSystemNode> rootNode;

	/**
	 * Reference pointer to the viewer instance. The viewer is the core of the graphical subsystem.
	 */ 
	osg::ref_ptr<osgViewer::Viewer> viewer;

};

}	// END NAMESPACE